pub struct SessionUploadSlot {
pub mid: String,
pub kind: MediaKind,
pub codecs: Vec<String>,
pub simulcast_encodings: Vec<SessionUploadEncoding>,
}Expand description
one offered upload media section
mid binds this slot to the SDP media section
kind, codecs and simulcast_encodings are compatibility metadata for
the protocol layer
Fields
mid: StringSDP media section id for this upload slot
kind: MediaKindaudio or video kind accepted on this media section
codecs: Vec<String>codec names accepted for this upload slot
simulcast_encodings: Vec<SessionUploadEncoding>simulcast layers the client may announce for this upload slot